hierarch.power.DataSimulator
============================

.. currentmodule:: hierarch.power

.. autoclass:: DataSimulator
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataSimulator.fit
      ~DataSimulator.generate
   
   

   
   
   